@@ -8,6 +8,7 @@ from yapsy.compat import ConfigParser, StringIO, str, builtin_str
 import tempfile
 import shutil
 
+import yapsy
 from yapsy import PLUGIN_NAME_FORBIDEN_STRING
 from yapsy.PluginManager import PluginManager
 from yapsy.PluginManager import IPlugin
@@ -60,7 +61,14 @@ class PluginFileAnalyzerWithInfoFileTest(unittest.TestCase):
 		analyzer = PluginFileAnalyzerWithInfoFile("mouf")
 		info_dict,cf_parser =  analyzer.getInfosDictFromPlugin(self.plugin_directory,
 															   os.path.basename(self.yapsy_plugin_path))
-		self.assertEqual(info_dict,{'website': 'http://mathbench.sourceforge.net', 'description': 'A simple plugin usefull for basic testing', 'author': 'Thibauld Nion', 'version': '0.1', 'path': '%s/SimplePlugin' % self.plugin_directory, 'name': 'Simple Plugin', 'copyright': '2014'})
+		self.assertEqual(info_dict,
+						 {'website': 'http://mathbench.sourceforge.net',
+	                      'description': 'A simple plugin usefull for basic testing',
+						  'author': 'Thibauld Nion',
+						  'version': '0.1',
+						  'path': '%s' % os.path.join(self.plugin_directory,"SimplePlugin"),
+						  'name': 'Simple Plugin',
+						  'copyright': '2014'})
 		self.assertTrue(isinstance(cf_parser,ConfigParser))
 		
 	def test_isValid_WithMultiExtensions(self):
@@ -192,8 +200,14 @@ class PluginFileLocatorTest(unittest.TestCase):
 	def test_default_plugins_place_is_parent_dir(self):
 		"""Test a non-trivial default behaviour introduced some time ago :S"""
 		pl = PluginFileLocator()
-		self.assertTrue("package/yapsy" in pl.plugins_places[0])
+		expected_yapsy_module_path = os.path.dirname(yapsy.__file__)
+		first_plugin_place = pl.plugins_places[0]
+		self.assertEqual(expected_yapsy_module_path, first_plugin_place)
 	
+	def test_given_string_as_plugin_places_raises_error(self):
+		pl = PluginFileLocator()
+		self.assertRaises(ValueError, pl.setPluginPlaces, "/mouf")
+
 	def test_locatePlugins(self):
 		pl = PluginFileLocator()
 		pl.setPluginPlaces([self.plugin_directory])
@@ -207,7 +221,7 @@ class PluginFileLocatorTest(unittest.TestCase):
 		self.assertTrue(isinstance(candidates[0][2],PluginInfo))
 		
 	def test_locatePlugins_when_plugin_is_symlinked(self):
-		if "win" in sys.platform:
+		if sys.platform.startswith("win"):
 			return
 		temp_dir = tempfile.mkdtemp()
 		try:
@@ -244,7 +258,7 @@ class PluginFileLocatorTest(unittest.TestCase):
 		self.assertTrue(isinstance(candidates[0][2],PluginInfo))
 	
 	def test_locatePlugins_when_plugin_is_a_symlinked_directory(self):
-		if "win" in sys.platform:
+		if sys.platform.startswith("win"):
 			return
 		temp_dir = tempfile.mkdtemp()
 		try:
@@ -301,6 +315,8 @@ class PluginFileLocatorTest(unittest.TestCase):
 			shutil.rmtree(temp_dir)
 			
 	def test_locatePlugins_recursively_when_plugin_is_a_symlinked_directory(self):
+		if sys.platform.startswith("win"):
+			return
 		temp_dir = tempfile.mkdtemp()
 		try:
 			temp_sub_dir = os.path.join(temp_dir,"plugins")
@@ -326,6 +342,8 @@ class PluginFileLocatorTest(unittest.TestCase):
 			shutil.rmtree(temp_dir)
 	
 	def test_locatePlugins_recursively_when_plugin_parent_dir_is_a_symlinked_directory(self):
+		if sys.platform.startswith("win"):
+			return
 		# This actually reproduced the "Plugin detection doesn't follow symlinks" bug
 		# at http://sourceforge.net/p/yapsy/bugs/19/
 		temp_dir = tempfile.mkdtemp()
